/*
 The Bluetooth Library for client-server communication
 Copyright (C) 2006 Martin Vysny

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 */
package net.sf.btw.btlib;

import java.io.DataInputStream;

/**
 * <p>
 * Listens for events on client.
 * </p>
 * <p>
 * Generally, event handlers should not fire an exception while in the handler.
 * If an exception is thrown, it is logged and
 * {@link IErrorListener#errorOccured(byte, int, boolean, Exception)} is called.
 * If the exception is thrown while a connection is being created the connection
 * will be destroyed.
 * </p>
 * @author Martin Vysny
 */
public interface IClientListener extends IErrorListener {
	/**
	 * The client is connected to the server.
	 * @param id the server ID of this client.
	 */
	void connected(final byte id);

	/**
	 * Server has disconnected this client, or an error occured. This client is
	 * no longer connected to a server and needs reconnect.
	 */
	void disconnected();

	/**
	 * <p>
	 * A message has arrived from the server. You may read the message from the
	 * stream.
	 * </p>
	 * <p>
	 * Warning: do NOT close the stream so it may be eventually reused.
	 * </p>
	 * 
	 * @param message
	 *            the message contents.
	 * @param messageLength
	 *            the length of data contained in the message array
	 * @param stream
	 *            stream reading bytes from the message, initially positioned
	 *            over the first byte of the message.
	 */
	void messageArrived(byte[] message, int messageLength,
			DataInputStream stream);

}
