/*
 The Bluetooth Library for client-server communication
 Copyright (C) 2006 Martin Vysny

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 */
package net.sf.btw.btlib;

/**
 * Informs peers about errors. The error is already logged when the method is
 * invoked.
 * 
 * @author Martin Vysny
 */
public interface IErrorListener {
	/**
	 * Notifies that an error happened.
	 * 
	 * @param peerId
	 *            error occured during communication with this peer. Server has always peer Id
	 *            of {@link Peer#SERVER_ID}.
	 * @param errorHint
	 *            where the error occured.
	 * @param listenerError
	 *            If <code>true</code> then the error occured while calling a
	 *            listener method. This is considered a program failure which
	 *            btlib cannot remedy. If this error occurs during the
	 *            connection creation then the connection is closed - we
	 *            consider that the program failed to initialize and will
	 *            probably fail again in the future when receiving a packet.
	 * @param ex
	 *            exception.
	 */
	void errorOccured(final byte peerId, final int errorHint,
			final boolean listenerError, final Exception ex);

	/**
	 * Error occured while waiting for a connection. This means that no more
	 * connections will be accepted by the server.
	 */
	public final static int ERROR_HINT_WAITING_FOR_CONNECTION = 0;

	/**
	 * Error occured while opening connection. This means that the connection
	 * will not be opened.
	 */
	public final static int ERROR_HINT_OPENING_CONNECTION = 3;

	/**
	 * Error occured while closing a connection. This error may be ignored as
	 * there is nothing much to do with it :)
	 */
	public final static int ERROR_HINT_CLOSING_CONNECTION = 1;

	/**
	 * Error occured while sending or receiving data through the connection. The
	 * connection will be closed immediately.
	 */
	public final static int ERROR_HINT_COMMUNICATING = 2;

}
